@@ -1,6 +1,6 @@
 from bread import views as breadviews
 from bread.utils.urls import autopath, default_model_paths, model_urlname, reverse_model
-from bread.views import AddView, EditView
+from bread.views import AddView, BrowseView, EditView
 from django.views.generic import RedirectView
 
 import basxconnect.core.views.tag_views
@@ -121,7 +121,10 @@ urlpatterns = [
     *default_model_paths(
         models.Term,
         addview=AddView._with(fields=["term", "vocabulary"]),
-        browseview=TermsBrowseView,
+        editview=EditView._with(fields=["term", "slug"]),
+        browseview=TermsBrowseView._with(
+            rowclickaction=BrowseView.gen_rowclickaction("edit", return_to_current=True)
+        ),
     ),
     *default_model_paths(
         models.Vocabulary,
@@ -167,28 +170,12 @@ urlpatterns = [
         urlname=model_urlname(models.Postal, "ajax_add"),
     ),
     autopath(
-        person_modals_views.NaturalPersonEditRemarksView.as_view(),
-        urlname=model_urlname(models.NaturalPerson, "ajax_edit_remarks"),
+        EditView._with(fields=["remarks"]).as_view(model=models.Person),
+        urlname=model_urlname(models.Person, "ajax_edit_remarks"),
     ),
     autopath(
-        person_modals_views.LegalPersonEditRemarksView.as_view(),
-        urlname=model_urlname(models.LegalPerson, "ajax_edit_remarks"),
-    ),
-    autopath(
-        person_modals_views.PersonAssociationEditRemarksView.as_view(),
-        urlname=model_urlname(models.PersonAssociation, "ajax_edit_remarks"),
-    ),
-    autopath(
-        person_modals_views.NaturalPersonEditTagsView.as_view(),
-        urlname=model_urlname(models.NaturalPerson, "ajax_edit_tags"),
-    ),
-    autopath(
-        person_modals_views.LegalPersonEditTagsView.as_view(),
-        urlname=model_urlname(models.LegalPerson, "ajax_edit_tags"),
-    ),
-    autopath(
-        person_modals_views.PersonAssociationEditTagsView.as_view(),
-        urlname=model_urlname(models.PersonAssociation, "ajax_edit_tags"),
+        EditView._with(fields=["tags"]).as_view(model=models.Person),
+        urlname=model_urlname(models.Person, "ajax_edit_tags"),
     ),
     *[
         autopath(
