@@ -45,6 +45,7 @@ class NaturalPersonEditPersonalDataView(EditView):
         "autogenerate_displayname",
         "first_name",
         "last_name",
+        "gender",
         "date_of_birth",
         "profession",
         "deceased",
@@ -85,6 +86,7 @@ class NaturalPersonEditPersonalDataView(EditView):
                 ),
                 R(C(F("first_name"))),
                 R(C(F("last_name"))),
+                R(C(F("gender"))),
                 R(C(F("date_of_birth"))),
                 R(C(F("profession"))),
                 R(C(F("deceased"))),
@@ -239,6 +241,9 @@ class EditEmailAddressView(EditView):
                 "",
             ),
         ]
+        if self.ajax_urlparameter in self.request.GET:
+            return layout.forms.Form(hg.C("form"), *form_fields)
+
         return layout.grid.Grid(
             hg.H3(_("Edit Email")),
             layout.grid.Row(
@@ -262,45 +267,3 @@ class AddEmailAddressView(AddView):
         ret = super().post(request, *args, **kwargs)
         self.object.person.save()
         return ret
-
-
-class NaturalPersonEditRemarksView(EditView):
-    model = models.NaturalPerson
-    fields = [
-        "remarks",
-    ]
-
-
-class LegalPersonEditRemarksView(EditView):
-    model = models.LegalPerson
-    fields = [
-        "remarks",
-    ]
-
-
-class PersonAssociationEditRemarksView(EditView):
-    model = models.PersonAssociation
-    fields = [
-        "remarks",
-    ]
-
-
-class NaturalPersonEditTagsView(EditView):
-    model = models.NaturalPerson
-    fields = [
-        "tags",
-    ]
-
-
-class LegalPersonEditTagsView(EditView):
-    model = models.LegalPerson
-    fields = [
-        "tags",
-    ]
-
-
-class PersonAssociationEditTagsView(EditView):
-    model = models.PersonAssociation
-    fields = [
-        "tags",
-    ]
