@@ -46,7 +46,11 @@ def ADD_ADDRESS_LAYOUT():
         layout.grid.Row(
             layout.grid.Col(_("Address"), style="font-weight: 700; margin-bottom: 2rem")
         ),
-        layout.grid.Row(layout.grid.Col(layout.forms.FormField("address"))),
+        layout.grid.Row(
+            layout.grid.Col(
+                layout.forms.FormField("address", inputelement_attrs={"rows": "2"})
+            )
+        ),
         layout.grid.Row(
             layout.grid.Col(
                 layout.forms.FormField("postcode"),
@@ -300,7 +304,14 @@ class AddPersonWizard(PermissionRequiredMixin, BreadView, NamedUrlSessionWizardV
                 self.get_steps(),
                 style="margin-bottom: 2rem",
             ),
-            generate_wizard_form(self.get_form()._layout),
+            layout.grid.Grid(
+                layout.grid.Row(
+                    layout.grid.Col(
+                        generate_wizard_form(self.get_form()._layout), width=8
+                    )
+                ),
+                gutter=False,
+            ),
             hg.SCRIPT(
                 hg.mark_safe(
                     r"""
